import pygame


def long_pause(dev):
    try:
        pygame.mixer.music.pause()
        if dev:
            print("Rafflesia Audio / long_pause: long 일시정지")
    except Exception as e:
        print(e)



import pygame


def long_load(filepath, dev):
    try:
        pygame.mixer.music.load(filepath)
        if dev:
            print(f"Rafflesia Audio / long_load: {filepath} long에 load됨")
    except Exception as e:
        print(e)



from Rafflesia.Audio import busy
from Rafflesia.Audio import effects
from Rafflesia.Audio import load
from Rafflesia.Audio import play
from Rafflesia.Audio import pos
from Rafflesia.Audio import queue
from Rafflesia.Audio import rewind
from Rafflesia.Audio import stop
from Rafflesia.Audio import pause
from Rafflesia.Audio import unpause
from Rafflesia.Audio import volume
import pygame

pygame.mixer.set_num_channels(2048)


class AudioManager:
    def __init__(self, dev=False):
        self.dev = dev
        super(AudioManager, self).__init__()

    def long_load(self, filepath):
        load.long_load(filepath, self.dev)

    def long_queue(self, filepath):
        queue.long_queue(filepath, self.dev)

    def long_play(self, loops=0, start=0.0, infinityloop=False):
        play.long_play(loops, start, infinityloop, self.dev)

    def long_rewind(self):
        rewind.long_rewind(self.dev)

    def long_stop(self):
        stop.long_stop(self.dev)

    def long_pause(self):
        pause.long_pause(self.dev)

    def long_unpause(self):
        unpause.long_unpause(self.dev)

    def long_get_busy(self):
        return busy.long_get_busy(self.dev)

    def long_get_volume(self):
        return volume.long_get_volume(self.dev)

    def long_set_volume(self, value):
        volume.long_set_volume(value, self.dev)

    def long_get_pos(self):
        return pos.long_get_pos(self.dev)

    def long_set_pos(self, value):
        pos.long_set_pos(value, self.dev)

    def long_fadeout(self, value):
        effects.long_fadeout(value, self.dev)



import pygame


def long_fadeout(time, dev):
    try:
        pygame.mixer.music.fadeout(time)
        if dev:
            print(f"Rafflesia Audio / long_fadeout: long {time} fade out")
    except Exception as e:
        print(e)



import pygame


def long_unpause(dev):
    try:
        pygame.mixer.music.unpause()
        if dev:
            print("Rafflesia Audio / long_unpause: long 일시정지 해제")
    except Exception as e:
        print(e)



import pygame


def long_get_busy(dev):
    try:
        if dev:
            if pygame.mixer.music.get_busy():
                print("Rafflesia Audio / long_busy: long 재생 중")
            else:
                print("Rafflesia Audio / long_busy: long 재생 중 x")
        return pygame.mixer.music.get_busy()
    except Exception as e:
        print(e)



import subprocess
import platform


def build(main, company_name, product_version, deploy_dir_name, withconsole, dev):
    try:
        system = platform.system()
        if dev:
            print(system)
        if system == 'Windows':
            if withconsole:
                command = f"python -m nuitka --mingw64 --show-modules --follow-imports " \
                          f"--windows-disable-console --enable-plugin=numpy --windows-company-name={company_name} " \
                          f"--windows-product-version={product_version} --output-dir={deploy_dir_name} {main}"
            else:
                command = f"python -m nuitka --mingw64 --show-modules --follow-imports " \
                          f"--enable-plugin=numpy --windows-company-name={company_name} " \
                          f"--windows-product-version={product_version} --output-dir={deploy_dir_name} {main}"
            if dev:
                print(command)
            subprocess.run(command.split(' '), shell=True)

        elif system == 'Linux':
            print(system)
        elif system == 'Darwin':
            print(system)
        else:
            print("OS를 알 수 없음")
    except Exception as e:
        print(e)



from Rafflesia.Utils import build
from Rafflesia.Utils import requirements_txt


class UtilsManager:
    def __init__(self, dev=True):
        self.dev = dev
        super(UtilsManager, self).__init__()

    def build(self, main, company_name="QU4R7Z", product_version=1.0, dirname="Rafflesia-deploy", withconsole=True):
        build.build(main, company_name, product_version, dirname, withconsole, self.dev)

    def requirements_txt(self):
        requirements_txt.run(self.dev)
